@@ -2,7 +2,7 @@
 sentry
 ~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 import os
@@ -47,6 +47,3 @@ def get_version():
 
 __build__ = get_revision()
 __docformat__ = 'restructuredtext en'
-
-# We store global interpreter state in here
-environment = {}
