@@ -1,6 +1,15 @@
+"""
+sentry.utils.strings
+~~~~~~~~~~~~~~~~~~~~
+
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
+"""
 import base64
 import zlib
 
+from django.utils.encoding import smart_unicode
+
 
 def truncatechars(value, arg):
     """
@@ -13,7 +22,7 @@ def truncatechars(value, arg):
     except ValueError:  # Invalid literal for int().
         return value  # Fail silently.
     if len(value) > length:
-        return value[:length] + '...'
+        return value[:length - 3] + '...'
     return value
 
 
@@ -27,3 +36,11 @@ def decompress(value):
 
 def gunzip(value):
     return zlib.decompress(value, 16 + zlib.MAX_WBITS)
+
+
+def strip(value):
+    if not value:
+        return ''
+    if not isinstance(value, basestring):
+        return smart_unicode(value)  # fuck it
+    return smart_unicode(value).strip()
